@@ -1,8 +1,9 @@
 from ..base_object import *
-from ..attributes import Animation, Data
+from ..attributes import Animation, Data, Color
 from ..utils import *
 import uuid
 
+DEFAULT_COLOR = Color(128,128,128)
 
 class Object(BaseObject):
     """
@@ -45,7 +46,8 @@ class Object(BaseObject):
 
         # print warning if object is being created with the same id as an existing object
         if Object.exists(object_id):
-            print("[WARNING]", f"An object with object_id of {object_id} was already created. The previous object will be overwritten.")
+            if not Object.get(object_id).persist:
+                print("[WARNING]", f"An object with object_id of {object_id} was already created. The previous object will be overwritten.")
             Object.remove(Object.get(object_id))
 
         # setup attributes in the "data" field
@@ -64,6 +66,9 @@ class Object(BaseObject):
         self.update_handler = update_handler
         self.animations = []
 
+        # add default color
+        self.update_attributes(color=DEFAULT_COLOR)
+
         # add current object to all_objects dict
         Object.add(self)
 
